@@ -5,10 +5,8 @@ import (
 	"flag"
 	"fmt"
 	"os"
-	"path/filepath"
 	"strings"
 
-	"github.com/sethvargo/ratchet/internal/atomic"
 	"github.com/sethvargo/ratchet/internal/concurrency"
 	"github.com/sethvargo/ratchet/parser"
 	"github.com/sethvargo/ratchet/resolver"
@@ -56,7 +54,7 @@ func (c *UpgradeCommand) Flags() *flag.FlagSet {
 		"maximum number of concurrent resolutions")
 	f.StringVar(&c.flagParser, "parser", "actions", "parser to use")
 	f.StringVar(&c.flagOut, "out", "", "output path (defaults to input file)")
-	f.BoolVar(&c.flagPin, "pin", true, "pin resolved upgraded versions (defaults to true)")
+	f.BoolVar(&c.flagPin, "pin", true, "pin resolved upgraded versions")
 
 	return f
 }
@@ -77,48 +75,31 @@ func (c *UpgradeCommand) Run(ctx context.Context, originalArgs []string) error {
 		return fmt.Errorf("failed to create resolver: %w", err)
 	}
 
-	fsys := os.DirFS(".")
-
-	files, err := loadYAMLFiles(fsys, args)
+	loadResult, err := loadYAMLFiles(os.DirFS("."), args)
 	if err != nil {
 		return err
 	}
 
-	if len(files) > 1 && c.flagOut != "" && !strings.HasSuffix(c.flagOut, "/") {
+	if len(loadResult) > 1 && c.flagOut != "" && !strings.HasSuffix(c.flagOut, "/") {
 		return fmt.Errorf("-out must be a directory when upgrading multiple files")
 	}
 
-	if err := parser.Unpin(ctx, files.nodes()); err != nil {
+	if err := parser.Unpin(ctx, loadResult.nodes()); err != nil {
 		return fmt.Errorf("failed to unpin refs: %w", err)
 	}
 
-	if err := parser.Upgrade(ctx, res, par, files.nodes(), c.flagConcurrency); err != nil {
+	if err := parser.Upgrade(ctx, res, par, loadResult.nodes(), c.flagConcurrency); err != nil {
 		return fmt.Errorf("failed to upgrade refs: %w", err)
 	}
 
 	if c.flagPin {
-		if err := parser.Pin(ctx, res, par, files.nodes(), c.flagConcurrency); err != nil {
+		if err := parser.Pin(ctx, res, par, loadResult.nodes(), c.flagConcurrency); err != nil {
 			return fmt.Errorf("failed to pin upgraded refs: %w", err)
 		}
 	}
 
-	for _, f := range files {
-		outFile := c.flagOut
-		if strings.HasSuffix(c.flagOut, "/") {
-			outFile = filepath.Join(c.flagOut, f.path)
-		}
-		if outFile == "" {
-			outFile = f.path
-		}
-
-		final, err := f.marshalYAML()
-		if err != nil {
-			return fmt.Errorf("failed to marshal yaml for %s: %w", f.path, err)
-		}
-
-		if err := atomic.Write(f.path, outFile, strings.NewReader(final)); err != nil {
-			return fmt.Errorf("failed to save file %s: %w", outFile, err)
-		}
+	if err := loadResult.writeYAMLFiles(c.flagOut); err != nil {
+		return fmt.Errorf("failed to save files: %w", err)
 	}
 
 	return nil
