@@ -20,7 +20,7 @@ func TestActions_Parse(t *testing.T) {
 			in: `
 jobs:
 `,
-			exp: []string{},
+			exp: nil,
 		},
 		{
 			name: "uses",
@@ -91,23 +91,36 @@ runs:
 				"container://ubuntu@sha256:47f14534bda344d9fe6ffd6effb95eefe579f4be0d508b7445cf77f61a0e5724",
 			},
 		},
+		{
+			name: "ignores_interpolated",
+			in: `
+jobs:
+  my_job:
+    container:
+      image: 'ghcr.io/${{ github.repository }}/container:1.2.3'
+    steps:
+      - uses: 'actions/${{ github.sha }}'
+
+`,
+			exp: nil,
+		},
 	}
 
 	for _, tc := range cases {
-		tc := tc
-
 		t.Run(tc.name, func(t *testing.T) {
 			t.Parallel()
 
-			m := helperStringToYAML(t, tc.in)
+			nodes := map[string]*yaml.Node{
+				"test.yml": helperStringToYAML(t, tc.in),
+			}
 
-			refs, err := new(Actions).Parse([]*yaml.Node{m})
+			refs, err := new(Actions).Parse(nodes)
 			if err != nil {
 				t.Fatal(err)
 			}
 
 			if got, want := refs.Refs(), tc.exp; !reflect.DeepEqual(got, want) {
-				t.Errorf("expected %q to be %q", got, want)
+				t.Errorf("expected %#v to be %#v", got, want)
 			}
 		})
 	}
