@@ -20,7 +20,7 @@ func TestCircleCI_Parse(t *testing.T) {
 			in: `
 executors:
 `,
-			exp: []string{},
+			exp: nil,
 		},
 		{
 			name: "executor",
@@ -51,14 +51,14 @@ jobs:
 	}
 
 	for _, tc := range cases {
-		tc := tc
-
 		t.Run(tc.name, func(t *testing.T) {
 			t.Parallel()
 
-			m := helperStringToYAML(t, tc.in)
+			nodes := map[string]*yaml.Node{
+				"test.yml": helperStringToYAML(t, tc.in),
+			}
 
-			refs, err := new(CircleCI).Parse([]*yaml.Node{m})
+			refs, err := new(CircleCI).Parse(nodes)
 			if err != nil {
 				t.Fatal(err)
 			}
